function headway_register_element_click(option){		
	var element_selector = option.attr('selector');
	
	// Make sure the element isn't a div.headway-leaf (leaf).  Otherwise it'll kill the controls due to hierarchy.
	if(!hwiframe(element_selector).hasClass('headway-leaf')){
		hwiframe(element_selector).hover(function(){
			var nice_name = option.text();
			var element = option.val();
			
			jQuery('div#inspector').html('<p><strong>' + nice_name + '</strong></p><p class="selector"><b>CSS Selector:</b> <code>' + element + '</code></p>');
		});
	}
	
	hwiframe(element_selector).click(function(event){
		var form_name;
		var nice_name = option.text();
		var element = option.val();
		var design_widget = jQuery('div#design-editor-widget');
				
		if(!jQuery('div#inspector-container').hasClass('hidden')){			
			event.stopPropagation();

			form_name = headway_element_form_name(element);
						
			jQuery('div#colors').show();
			jQuery('.colors-inputs').hide();
			jQuery('table#colors-' + form_name).show();
			jQuery('span#colors-heading').text(nice_name);
						
			if(option.attr('fonts') == 'true'){
				jQuery('div#fonts').css('display', '');
			} else {
				jQuery('div#fonts').hide();
			}
			
			if(option.attr('colors') == 'true'){
				jQuery('div#colors').css('display', '');
			} else {
				jQuery('div#colors').hide();
			}
			
			jQuery('.fonts-inputs').hide();
			jQuery('table#fonts-' + form_name).show();
			jQuery('span#fonts-heading').text(nice_name);
			jQuery('option#option-' + form_name).attr('selected', 'selected');
		
			jQuery('p#callout').show();
		}
		
		return false;
	});
}


function headway_update_style(element, property, value){
	var element;
	var styling;
	
	styling = new Object();
	styling[property] = value;

	if(!stylesheet.update_rule(element, styling)){
		property = property.split('-');
		
		if(property.length == 1){
			property = property[0];
		} else if(property.length == 2){
			property = property[0] + property[1].substr(0, 1).toUpperCase() + property[1].substr(1);
		} else if(property.length == 3){
			property = property[0] + property[1].substr(0, 1).toUpperCase() + property[1].substr(1) + property[2].substr(0, 1).toUpperCase() + property[2].substr(1);
		}
		
		element = hwiframe(element);
		element.css(property, value);
	}
}

// Bind VE Check Boxes
function ve_check_function(input, value){
	var element;
	var property;
	var icon;
	
	element = input.attr('selector');

	if(input.hasClass('font-weight')){
		property = 'font-weight';
		icon = 'bold';
	} else if(input.hasClass('font-variant')){
		property = 'font-variant';
		icon = 'small-caps';
	} else if(input.hasClass('font-style')){
		property = 'font-style';
		icon = 'italic';
	} else if(input.hasClass('text-decoration')){ 
		property = 'text-decoration';
		icon = 'underline';
	} else {
		return false;
	}
	
	if(value == 'normal' || value == 'none'){
		input.attr('checked', false);
				
		input.parents('tr').find('.ve-icon-' + icon).removeClass('ve-icon-depressed');
	} else {
		input.attr('checked', true);
		
		input.parents('tr').find('.ve-icon-' + icon).addClass('ve-icon-depressed');
	}

	headway_update_style(element, property, value);

	headway_stop_ve_close();
}

function get_color_property(element){
	if(element.hasClass('color')) property = 'color';
	if(element.hasClass('background')) property = 'background';
	if(element.hasClass('border')) property = 'border-color';
	if(element.hasClass('top-border')) property = 'border-top-color';
	if(element.hasClass('right-border')) property = 'border-right-color';
	if(element.hasClass('bottom-border')) property = 'border-bottom-color';
	if(element.hasClass('left-border')) property = 'border-left-color';
	
	return property;
}

function purge_name_junk(element){
	return element.replace('width-', '')
		      .replace('-inherit-colors', '')
	  		  .replace('color-picker-', '')
			  .replace('color-', '')
			  .replace('-bottom-border', '')
			  .replace('-left-border', '')
			  .replace('-top-border', '')
			  .replace('-right-border', '')
			  .replace('-border', '')
			  .replace('-color', '')
			  .replace('-background-transparent', '')
			  .replace('-background', '')
			  .replace('font-', '')
			  .replace('-font-family', '')
			  .replace('-font-size', '')
			  .replace('-line-height', '')
			  .replace('-letter-spacing', '')
			  .replace('-text-transform', '')
			  .replace('-font-weight', '')
		      .replace('-font-style', '')
			  .replace('-font-variant', '');
}


function headway_bind_style_select_option(element){
	jQuery(element).click(function(){
		jQuery(this).siblings('div.selected-option').removeClass('selected-option');
		jQuery(this).addClass('selected-option');
		
		jQuery('a#load-style').show();
	});
	
	jQuery(element).children('.style-select-edit').click(function(){		
		headway_edit_style(jQuery(this).parent());
	});
}


function headway_edit_style(option){
	var option_text = option.children('span.select-option-text');
	var rename_input = jQuery('input#rename-style');
	
	rename_input.val(option_text.text());
	
	jQuery('input#style-settings-style-id').val(option.attr('id'));
	jQuery('input#style-settings-style-name').val(option_text.text());
	
	headway_open_box('edit-style');
}




function headway_design_editor() {		
	stylesheet = new ITStylesheet(jQuery('iframe#visual-editor-contents').contents()[0], {href: headway_settings['headway-css-url']}, 'find');
	
	headway_bind_style_select_option('div.headway-custom-select div.select-option');
	
	jQuery('a#save-style').click(function(){
		headway_open_box('save-style');
		
		return false;
	});

	// Bind Element Selector
	jQuery('select#element-selector').change(function(){	
		var english_name = jQuery(this).find(':selected').text();
		var id = jQuery(this).find(':selected').val();
		var nice_id = headway_element_form_name(id);
	
		jQuery('div#colors').show();
		jQuery('.colors-inputs').hide();
		jQuery('table#colors-' + nice_id).show();
		jQuery('span#colors-heading').text(english_name);

		if(jQuery('option#option-'+nice_id).attr('fonts') == 'true'){
			jQuery('div#fonts').css('display', '');
		} else {
			jQuery('div#fonts').hide();
		}
		
		if(jQuery('option#option-'+nice_id).attr('colors') == 'true'){
			jQuery('div#colors').css('display', '');
		} else {
			jQuery('div#colors').hide();
		}

		jQuery('.fonts-inputs').hide();
		jQuery('table#fonts-' + nice_id).show();
		jQuery('span#fonts-heading').text(english_name);

		jQuery('p#callout').show();
	});
	

	// Bind Callout Button
	jQuery('p#callout a').click(function(){
		hwiframe(jQuery('select#element-selector :selected').val()).highlightFade({speed: 1000});
		return false;
	});


	//Bind Visual Font
	documentBlurFunction = function(e){
		if(!jQuery(e.target).is('div.font-family-select-options-open, div.font-family-select-options-open *, span.font-family-select-button')){
			jQuery('div.font-family-select-options-open').removeClass('font-family-select-options-open');
			
			jQuery(document).unbind('click', documentBlurFunction);
		}
	}
	
	visual_font_selector_button_action = function($$, selector, select_input){
		var options = $$.siblings('div.' + selector);
				
		$$.addClass('select-button-options-open');
		
		options.addClass('font-family-select-options-open'); //Add the class for delegation and to not make a blur on every single one

		options.scrollTop(0); //Reset the scroll		
		options.scrollTop(options.children('.selected').position().top);

		jQuery(document).bind('click', documentBlurFunction);
	}
	
	visual_font_selector_option_action = function($$, selector, select_input, action){
		var options;
		
		if(typeof action == 'undefined' || !action) action = false;

		$$.parent().siblings('select' + select_input).val($$.attr('class').replace('selected', '').replace(' ', '')).trigger('change');
		
		if(action){
			options = $$.parents('div.font-family-select-options');
			
			$$.addClass('selected').siblings('.selected').removeClass('selected');
			
			options.siblings('span.font-family-select-button').removeClass('select-button-options-open').text($$.text()).css('fontFamily', $$.css('fontFamily'));

			options.removeClass('font-family-select-options-open');
		}
	}
	
	bind_visual_font_selector = function(selector, select_input){		
		jQuery('span.' + selector).bind('click', function(){
			visual_font_selector_button_action(jQuery(this), selector, select_input, true);
		});
		
		jQuery('div.' + selector).delegate('span', 'click', function(){
			visual_font_selector_option_action(jQuery(this), selector, select_input, true);
		});
	}
	
	//Normal Fonts
	jQuery('div#visual-editor-sidebar').delegate('span.font-family-select-button', 'click', function(){
		visual_font_selector_button_action(jQuery(this), 'font-family-select-options', '.font-family');
	});
	
	jQuery('div#visual-editor-sidebar div.font-family-select-options').delegate('span', 'click', function(){
		visual_font_selector_option_action(jQuery(this), 'font-family-select-options', '.font-family');
	});
	
	//Mass Fonts
	bind_visual_font_selector('mass-font-select-titles', '#mass-font-select-titles');
	bind_visual_font_selector('mass-font-select-content', '#mass-font-select-content');
	
	//Wizard Fonts
	bind_visual_font_selector('wizard-fonts-titles', '#wizard-fonts-titles');
	bind_visual_font_selector('wizard-fonts-content', '#wizard-fonts-content');
		

	// Bind actions to color boxes. 
	jQuery('div#de-tab').delegate('input.color-text', 'blur', function(){
		//Get the ID only
		var element = jQuery(this).attr('selector');
		var element_form_id = purge_name_junk(jQuery(this).attr('id'));
		
		//Figure Out Which Property
		var property = get_color_property(jQuery(this));
		
		//If inherit colors is checked, do not change colors	
		if(jQuery('#color-' + element_form_id + '-inherit-colors').is(':checked'))
			return false;
				
		var colorpicker = jQuery(this).attr('id').replace('color-', 'color-picker-');
		
		if(property == 'background'){
			jQuery('input#' + jQuery(this).attr('id').replace('-picker', '') + '-transparent').attr('checked', false);
		}
		
		jQuery('div#'+colorpicker).ColorPickerSetColor(jQuery(this).val());
		jQuery('div#'+colorpicker).children('.color-picker-color').css('background', '#'+jQuery(this).val());
	
		jQuery(this).val(jQuery(this).val());
	
		headway_update_style(element, property, '#' + jQuery(this).val());
	});

	
	headway_bind_color_selector_button('table.colors-inputs div.color-picker:not(.no-color-picker)');
	
	
	//Bind Leaf Columns Stuff
	jQuery('div#color-picker-leaf-columns-border-color').ColorPicker({
			onChange: function(hsb, hex, rgb, el){	
				var color_input = jQuery('input#leaf-columns-border-color');				

				color_input.val(hex);
			
				jQuery('div.leafs-column').css('borderRightColor', '#'+hex);
				jQuery('div#top-container').css('borderBottomColor', '#'+hex);				
				jQuery('div#bottom-container').css('borderTopColor', '#'+hex);				
								
				jQuery(el).children('.color-picker-color').css('background-color', '#'+hex);
				
				headway_stop_ve_close();
			},
			onSubmit: function(hsb, hex, rgb, el) {
				var color_input = jQuery('input#leaf-columns-border-color');
				var colorpicker_id = jQuery(el).data('colorpickerId');	
								
				color_input.val(hex);
			
				jQuery('div.leafs-column').css('borderRightColor', '#'+hex);
				jQuery('div#top-container').css('borderBottomColor', '#'+hex);				
				jQuery('div#bottom-container').css('borderTopColor', '#'+hex);

				jQuery(el).children('.color-picker-color').css('background-color', '#'+hex);
				
				jQuery(el).ColorPickerHide();
				
				jQuery('div#' + colorpicker_id).data('display', 'hidden');
				
				headway_stop_ve_close();				
			},
			onShow: function(colpkr){	
				var siblings = jQuery(this).parents('tr').siblings('tr');
				
				siblings.css('opacity', .5);
							
				return false;
			},
			onHide: function(colpkr){
				var siblings = jQuery(this).parents('tr').siblings('tr');
				
				siblings.css('opacity', 1);
			},
			onBeforeShow: function () {				
				jQuery(this).ColorPickerSetColor(jQuery('input#leaf-columns-border-color').val());
			}
	});
	headway_bind_color_selector_button('div#color-picker-leaf-columns-border-color');
	
	
	jQuery('select#leaf-columns-border-style').change(function(){
		if(jQuery(this).val() == 'double'){
			jQuery('div.leafs-column:not(.last-leafs-column)').css('borderRightStyle', 'double');
			jQuery('div.leafs-column:not(.last-leafs-column)').css('borderRightWidth', 3);
			jQuery('div.leafs-column:not(.last-leafs-column)').css('paddingRight', 7);
			
			jQuery('div#top-container').css('borderBottomStyle', 'double');
			jQuery('div#top-container').css('borderBottomWidth', 3);
			jQuery('div#top-container').css('paddingBottom', 13);
			
			jQuery('div#bottom-container').css('borderTopStyle', 'double');
			jQuery('div#bottom-container').css('borderTopWidth', 3);
			jQuery('div#bottom-container').css('paddingTop', 13);
		} else if(jQuery(this).val() == 'no-border'){
			jQuery('div.leafs-column:not(.last-leafs-column)').css('borderRightStyle', 'none');
			jQuery('div.leafs-column:not(.last-leafs-column)').css('borderRightWidth', 0);
			jQuery('div.leafs-column:not(.last-leafs-column)').css('paddingRight', 10);

			jQuery('div#top-container').css('borderBottomStyle', 'none');
			jQuery('div#top-container').css('borderBottomWidth', 0);
			jQuery('div#top-container').css('paddingBottom', 10);

			jQuery('div#bottom-container').css('borderTopStyle', 'none');
			jQuery('div#bottom-container').css('borderTopWidth', 0);
			jQuery('div#bottom-container').css('paddingTop', 10);
		} else {
			jQuery('div.leafs-column:not(.last-leafs-column)').css('borderRightWidth', 1);
			jQuery('div.leafs-column:not(.last-leafs-column)').css('paddingRight', 9);
			jQuery('div.leafs-column:not(.last-leafs-column)').css('borderRightStyle', jQuery(this).val());
			
			jQuery('div#top-container').css('borderBottomStyle', jQuery(this).val());
			jQuery('div#top-container').css('borderBottomWidth', 1);
			jQuery('div#top-container').css('paddingBottom', 15);
			
			jQuery('div#bottom-container').css('borderTopStyle', jQuery(this).val());
			jQuery('div#bottom-container').css('borderTopWidth', 1);
			jQuery('div#bottom-container').css('paddingTop', 15);
		}
	});
	

	// Bind action to border inputs.
	jQuery('div#de-tab').delegate('input.border-width', 'blur', function(){
		var element = jQuery(this).attr('selector');
		var property;
	
		if(jQuery(this).hasClass('border')) property = 'border-width';
		if(jQuery(this).hasClass('top-border')) property = 'border-top-width';
		if(jQuery(this).hasClass('right-border')) property = 'border-right-width';
		if(jQuery(this).hasClass('bottom-border')) property = 'border-bottom-width';
		if(jQuery(this).hasClass('left-border')) property = 'border-left-width';
		
		headway_update_style(element, property, jQuery(this).val() + 'px');
	
		headway_stop_ve_close();
	});


	// Bind selects
	jQuery('div#de-tab').delegate('select.font-select', 'change', function(){	
		var element = jQuery(this).attr('selector');
		var property;
		var value;
	
		if(jQuery(this).hasClass('font-family')) property = 'font-family';
		if(jQuery(this).hasClass('font-size')) property = 'font-size';
		if(jQuery(this).hasClass('line-height')) property = 'line-height';
		if(jQuery(this).hasClass('letter-spacing')) property = 'letter-spacing';
		if(jQuery(this).hasClass('text-transform')) property = 'text-transform';
		if(jQuery(this).hasClass('text-align')) property = 'text-align';

	
		if(property == 'font-size'){
			value = jQuery(this).val() + 'px';
		} else if(property == 'line-height'){
			value = jQuery(this).val() + '%';
		} else if(property == 'font-family'){
			value = headway_settings['fonts'][jQuery(this).val()]['family'];
			
			options = jQuery(this).siblings('div.font-family-select-options');
			selected_option = options.children('.' + jQuery(this).val())
			
			selected_option.addClass('selected').siblings('.selected').removeClass('selected');
			
			options.siblings('span.font-family-select-button').removeClass('select-button-options-open').text(selected_option.text()).css('fontFamily', selected_option.css('fontFamily'));

			options.removeClass('font-family-select-options-open');
		} else {
			value = jQuery(this).val();
		}
			
		headway_update_style(element, property, value);
	
		headway_stop_ve_close();
	});


	jQuery('div#de-tab').delegate('input.font-check', 'click', function(){
		var default_value;
		var property;
		var value;
		var element = jQuery(this).attr('selector');
	
		if(jQuery(this).hasClass('font-weight')) property = 'font-weight';
		if(jQuery(this).hasClass('font-variant')) property = 'font-variant';
		if(jQuery(this).hasClass('font-style')) property = 'font-style';
		if(jQuery(this).hasClass('text-decoration')) property = 'text-decoration';
		
		if(property == 'text-decoration'){
			default_value = 'none';
		} else {
			default_value = 'normal';
		}
		
		if(jQuery(this).is(":checked")){
			value = jQuery(this).val();
		} else {     
			value = default_value;
		}
		
		headway_update_style(element, property, value);
	
		headway_stop_ve_close();
		
		return false;
	});


	//Bind Transparency Check boxes
	jQuery('div#de-tab').delegate('input.background-transparent', 'click', function(){
		var element_form_id = purge_name_junk(jQuery(this).attr('id'));
		var element = jQuery(this).attr('selector');
		var value;
	
		if(jQuery(this).is(":checked")){
			value = 'transparent';
		} else {     
			value = '#'+jQuery('input#color-'+element_form_id+'-background').val();
		}	
		
		headway_update_style(element, 'background', value);

		headway_stop_ve_close();
	});

	function background_transparency_check_function(input, value){
		var element_form_id = purge_name_junk(input.attr('id'));
		var element = input.attr('selector');	
		
		//If inherit colors is checked, do not do anything	
		if(jQuery('#color-' + element_form_id + '-inherit-colors').is(':checked'))
			return false;
				
		if(value == 'on'){
			value = 'transparent';
			
			input.attr('checked', true);
		} else {     
			value = '#'+jQuery('input#color-'+element_form_id+'-background').val();
			
			input.attr('checked', false);
		}	
		
		headway_update_style(element, 'background', value);
		
		headway_stop_ve_close();
	}
	
	
	//Bind Transparency Check boxes
	jQuery('div#de-tab').delegate('input.inherit-colors', 'click', function(){
		var element_form_id = purge_name_junk(jQuery(this).attr('id'));
		var element = jQuery(this).attr('selector');
		var color_value;
		var background_color;
	
		if(jQuery(this).is(":checked")){
			color_value = null;
			background_color = null;
			
			jQuery(this).parent().parent().siblings('tr').hide();
		} else {     
			color_value = '#'+jQuery('input#color-'+element_form_id+'-color').val();
			background_value = '#'+jQuery('input#color-'+element_form_id+'-background').val();
			
			jQuery(this).parent().parent().siblings('tr').show();
		}	
		
		headway_update_style(element, 'color', color_value);
		headway_update_style(element, 'background', background_value);

		headway_stop_ve_close();
	});

	function inherit_colors_check_function(input, value){
		var element_form_id = purge_name_junk(input.attr('id'));
		var element = input.attr('selector');
		var color_value;
		var background_value;
			
		if(value == 'on'){
			input.attr('checked', true);
			
			input.parent().parent().siblings('tr').hide();
			
			color_value = null;
			background_value = null;

			headway_update_style(element, 'color', color_value);
			headway_update_style(element, 'background', background_value);
		} else {    
			input.attr('checked', false);
			
			input.parent().parent().siblings('tr').show();
		}
		
		headway_stop_ve_close();
	}


	// Bind Mass Font Select
	jQuery('select#mass-font-select-titles').change(function(){
		var mass_value = jQuery(this).val();
			
		jQuery('select.title-fonts:not(.mass-font-change)').val(mass_value).trigger('change');
	
		headway_stop_ve_close();
	});
	
	jQuery('select#mass-font-select-content').change(function(){
		var mass_value = jQuery(this).val();
	
		jQuery('select.font-family:not(.mass-font-change, .title-fonts)').val(mass_value).trigger('change');
	
	
		headway_stop_ve_close();
	});
	/////////////////////////
	
	
	jQuery('a#save-style-submit').click(function(){
		var style_name = jQuery('input#style-name').val();
		
		var color_primary = jQuery('input#color--period-header-link-text-inside-color').val();
		var color_secondary = jQuery('input#color-div-pound-navigation-background').val();
		var color_tertiary = jQuery('input#color--pound-tagline-color').val();
		
		var design_data = jQuery('.visual-editor-color-input, .visual-editor-font-input, .visual-editor-border-input').serialize();
		
		jQuery.post( 
			headway_blog_url+'/?headway-trigger=process&process=save-style&style-name=' + escape(style_name) + '&color-primary=' + escape(color_primary) + '&color-secondary=' + escape(color_secondary) + '&color-tertiary=' + escape(color_tertiary), 
			design_data,
			function(response){
				var style_id = response;
								
				jQuery('div#style-selector').append('<div class="select-option" id="style-' + style_id + '"><span class="select-option-text">' + style_name + '</span><div class="color-preview" style="background: #' + color_tertiary + ';"></div><div class="color-preview" style="background: #' + color_secondary + ';"></div><div class="color-preview" style="background: #' + color_primary + ';"></div><a href="#" class="style-select-edit select-edit">Edit</a></div>');
				
				jQuery('p#no-styles').hide();
				jQuery('a#load-style').show();
				
				jQuery('input#style-name').val('Style Name');
				
				headway_bind_style_select_option('div#style-' + style_id);
				
				headway_close_box('save-style');
			}
		);
		
		return false;
	});
	
	
	jQuery('a#export-style-button').click(function(){		
		var style_name = jQuery('select#export-style-selector').find(':selected').text();
		var style_id = jQuery('select#export-style-selector').find(':selected').val().replace('style-', '');
		
		var url = headway_blog_url + '/?headway-trigger=process&process=export-style&style-id='+escape(style_name + '-' + style_id) + '&style-name='+escape(style_name);
				
		window.open(url);	
		
		headway_close_box('export-window');	
				
		return false;
	});
	
	jQuery('a#import-style-box-button').click(function(){
		headway_open_box('style-import');
		
		return false;
	});
	
	
	var import_style = new qq.FileUploader({
		text: 'Import Style',
        element: jQuery('div#import-style')[0],
        action: headway_blog_url + '/?headway-trigger=process&process=ve-upload&what=style',
		allowedExtensions: ['hwstyle', 'txt'],
	    onComplete: function(id, fileName, response){
			var fileName = escape(response.filename);
							
			jQuery.ajax({
			  type: 'POST',
			  data: {'path':fileName},
			  url: headway_blog_url+'/?headway-trigger=process&process=import-style&callback=?',
			  dataType: 'json',
			  success: function(data){				
					var style_name = data['style-name'];
					
					if(data['color-primary']){
						var color_primary = data['color-primary'];
						var color_secondary = data['color-secondary'];
						var color_tertiary = data['color-tertiary'];
						
						var colors = '<div class="color-preview" style="background: #' + color_tertiary + ';"></div><div class="color-preview" style="background: #' + color_secondary + ';"></div><div class="color-preview" style="background: #' + color_primary + ';"></div>';
					} else {
						var colors = '';
					}
					
					var style_id = data['style-id'];

					jQuery('div#style-selector').append('<div class="select-option" id="style-' + style_id + '"><span class="select-option-text">' + style_name + '</span>' + colors + '<a href="#" class="style-select-edit select-edit">Edit</a></div>');
					
					jQuery('p#no-styles').hide();
					jQuery('a#load-style').show();
					
					headway_bind_style_select_option('div#style-' + style_id);
					
					headway_stop_ve_close();
				  }
			});
			
			jQuery('div#import-style ul.qq-upload-list li.qq-upload-success').remove();
			
		}
    });

	
	jQuery('a#load-style').click(function(){
		if(confirm('Are you sure?  Loading a style will allow you to see the style, but the new style will NOT be applied unless you click the Save All Changes button.') === false) return false;
		
		var style_name = jQuery('div#style-selector .selected-option span.select-option-text').text();
		var style_id = jQuery('div#style-selector .selected-option').attr('id').replace('style-', '');
		
		jQuery('div#visual-editor-working').show().animate({'opacity':1}, 250);
		jQuery('div#ve-working-overlay').show().animate({'opacity':1}, 250, false, function(){
			jQuery.ajax({
			  type: 'POST',
			  data: {'style-name':escape(style_name + '-' + style_id)},
			  url: headway_blog_url+'/?headway-trigger=process&process=load-style&callback=?',
			  dataType: 'json',
			  success: function(data){
					var style;
					 
					if(typeof data['styles'] == 'undefined'){
						style = data;
					} else {
						style = data['styles'];
					}

					var line_height_percentage_calc = false;
					var line_height_original = new Array();
					
					for (var i=0;i<style.length;i++){
						var value = style[i].value.toString();

						if(style[i].property_type == 'sizing'){
							style[i].property_type = 'width';

							if(value == 'zero') value = '0';
						}
																								
						style[i].property = style[i].property.replace('-width', '');

						if(jQuery('#'+style[i].property_type+'-'+style[i].element+'-'+style[i].property).length == 0){
							continue;
						}

						if(style[i].property == 'line-height' && value < 50){
							var line_height_percentage_calc = true;
							
							line_height_original[style[i].element] = value;
						}
							
						if(style[i].property == 'font-weight' || style[i].property == 'font-style' || style[i].property == 'text-decoration' || style[i].property == 'font-variant'){
							ve_check_function(jQuery('#'+style[i].property_type+'-'+style[i].element+'-'+style[i].property), value);
							
							continue;
						} else if(style[i].property == 'background-transparent'){
							background_transparency_check_function(jQuery('#'+style[i].property_type+'-'+style[i].element+'-'+style[i].property), value);
							
							continue;
						} else if(style[i].property == 'inherit-colors'){
							inherit_colors_check_function(jQuery('#'+style[i].property_type+'-'+style[i].element+'-'+style[i].property), value);
							
							continue;
						}
						
						if(jQuery('#'+style[i].property_type+'-'+style[i].element+'-'+style[i].property).length > 0){
							var input = jQuery('#'+style[i].property_type+'-'+style[i].element+'-'+style[i].property);
														
							if(style[i].property == 'font-family' && style[i].value.indexOf(',') >= 0){		
								if(value == 'trebuchet ms, sans-serif' || value == 'tahoma, sans-serif'){
									value = 'helvetica, sans-serif';
								}
																						
								value = headway_settings['font-families'][value]['id'];
																
								if(typeof value === 'undefined' || !value){
									value = 'helvetica';
								}
							}

							input.val(value).trigger('blur').trigger('change');
														
							if(style[i].property == 'text-transform'){
								input.parents('tr').find('span.ve-icon-uppercase, span.ve-icon-lowercase').removeClass('ve-icon-depressed');

								if(input.val() == 'lowercase'){
									input.parents('tr').find('span.ve-icon-lowercase').addClass('ve-icon-depressed');
								} else if(input.val() == 'uppercase'){
									input.parents('tr').find('span.ve-icon-uppercase').addClass('ve-icon-depressed');
								} else {
									input.parents('tr').find('span.ve-icon-uppercase, span.ve-icon-lowercase').removeClass('ve-icon-depressed');
								}
							}
							
							if(style[i].property == 'text-align'){								
								input.parents('tr').find('span.ve-icon-align-toggle').removeClass('ve-icon-depressed');

								if(input.val() == 'left'){
									input.parents('tr').find('span.ve-icon-align-left').addClass('ve-icon-depressed');
								} else if(input.val() == 'center'){
									input.parents('tr').find('span.ve-icon-align-center').addClass('ve-icon-depressed');
								} else if(input.val() == 'right'){
									input.parents('tr').find('span.ve-icon-align-right').addClass('ve-icon-depressed');
								}
							}
						}
					}
										
					if(line_height_percentage_calc){
						jQuery('select.line-height').each(function(){
							var this_id = jQuery(this).attr('id');
							var font_size_select = this_id.replace('-line-height', '-font-size');
							var element = this_id.replace('-line-height', '').replace('font-', '');
						
							var font_size = jQuery('select#' + font_size_select).val();

							jQuery(this).val(Math.round((Math.round((line_height_original[element]/font_size)*10)/10)*100)).trigger('change');
						});
					}

					jQuery('div#visual-editor-working, div#ve-working-overlay').animate({'opacity':0}, 250, false, function(){ 
						jQuery('div#visual-editor-working, div#ve-working-overlay').hide();
					});
					
					headway_stop_ve_close();
			  }
			});
		});
		
		return false;
	});
	
	
	jQuery('a#save-style-settings-button').click(function(){
		var style_id = jQuery('input#style-settings-style-id').val();
		var style_name = jQuery('input#style-settings-style-name').val();
		var rename_input = jQuery('input#rename-style');
		
		jQuery.ajax({
			type: 'POST',
			data: {'style-id': style_id, 'style-name': style_name, 'style-new-name': rename_input.val()},
			url: headway_blog_url+'/?headway-trigger=process&process=rename-style',
			async: false,
			success: function(data){	
				option_text.text(rename_input.val());

				headway_close_box('edit-style');
			}
		});

		return false;
	});

	jQuery('a#delete-style-button').click(function(){
		var style_id = jQuery('input#style-settings-style-id').val();
		var style_name = jQuery('input#style-settings-style-name').val();

		if(confirm('Are you sure?') === true){			
			jQuery.ajax({
				type: 'POST',
				data: {'style-id': style_id, 'style-name': style_name},
				url: headway_blog_url+'/?headway-trigger=process&process=delete-style',
				async: false,
				success: function(data){	
					jQuery('div#'+style_id).remove();

				    headway_close_box('edit-style');

					if(jQuery('div#style-selector div.select-option').length == 0){
						jQuery('p#no-styles').show();
						jQuery('a#load-style').hide();
					}
				}
			});
		}

		return false;
	});
	
	
	jQuery('span.ve-icon-style-toggle').click(function(){
		jQuery(this).toggleClass('ve-icon-depressed');
		
		if(jQuery(this).hasClass('ve-icon-bold')){
			if(jQuery(this).hasClass('ve-icon-depressed')){
				jQuery('input#font-' + jQuery(this).attr('element') + '-font-weight').attr('checked', true).trigger('click');
			} else {
				jQuery('input#font-' + jQuery(this).attr('element') + '-font-weight').attr('checked', false).trigger('click');
			}		
		}
		
		if(jQuery(this).hasClass('ve-icon-italic')){
			if(jQuery(this).hasClass('ve-icon-depressed')){
				jQuery('input#font-' + jQuery(this).attr('element') + '-font-style').attr('checked', true).trigger('click');
			} else {
				jQuery('input#font-' + jQuery(this).attr('element') + '-font-style').attr('checked', false).trigger('click');
			}		
		}
		
		if(jQuery(this).hasClass('ve-icon-underline')){
			if(jQuery(this).hasClass('ve-icon-depressed')){
				jQuery('input#font-' + jQuery(this).attr('element') + '-text-decoration').attr('checked', true).trigger('click');
			} else {
				jQuery('input#font-' + jQuery(this).attr('element') + '-text-decoration').attr('checked', false).trigger('click');
			}		
		}
		
		if(jQuery(this).hasClass('ve-icon-small-caps')){
			if(jQuery(this).hasClass('ve-icon-depressed')){
				jQuery('input#font-' + jQuery(this).attr('element') + '-font-variant').attr('checked', true).trigger('click');
				jQuery('select#font-' + jQuery(this).attr('element') + '-text-transform').val('none').trigger('change');
				jQuery(this).siblings('.ve-icon-lowercase, .ve-icon-uppercase').removeClass('ve-icon-depressed');
			} else {
				jQuery('input#font-' + jQuery(this).attr('element') + '-font-variant').attr('checked', false).trigger('click');
			}
		}
		
		if(jQuery(this).hasClass('ve-icon-uppercase')){
			if(jQuery(this).hasClass('ve-icon-depressed')){
				jQuery('select#font-' + jQuery(this).attr('element') + '-text-transform').val('uppercase').trigger('change');
				jQuery('input#font-' + jQuery(this).attr('element') + '-font-variant').attr('checked', false).trigger('click');
				jQuery(this).siblings('.ve-icon-lowercase, .ve-icon-small-caps').removeClass('ve-icon-depressed');
			} else {
				jQuery('select#font-' + jQuery(this).attr('element') + '-text-transform').val('none').trigger('change');
			}
		}

		if(jQuery(this).hasClass('ve-icon-lowercase')){
			if(jQuery(this).hasClass('ve-icon-depressed')){
				jQuery('select#font-' + jQuery(this).attr('element') + '-text-transform').val('lowercase').trigger('change');
				jQuery('input#font-' + jQuery(this).attr('element') + '-font-variant').attr('checked', false).trigger('click');
				jQuery(this).siblings('.ve-icon-uppercase, .ve-icon-small-caps').removeClass('ve-icon-depressed');
			} else {
				jQuery('select#font-' + jQuery(this).attr('element') + '-text-transform').val('none').trigger('change');
			}
		}
	});
	
	jQuery('span.ve-icon-align-toggle').click(function(){
		jQuery('span.ve-icon-align-toggle').removeClass('ve-icon-depressed');
		jQuery(this).addClass('ve-icon-depressed');
		
		if(jQuery(this).hasClass('ve-icon-align-left')){
			jQuery('select#font-' + jQuery(this).attr('element') + '-text-align').val('left').trigger('change');
		}
		
		if(jQuery(this).hasClass('ve-icon-align-center')){
			jQuery('select#font-' + jQuery(this).attr('element') + '-text-align').val('center').trigger('change');
		}
		
		if(jQuery(this).hasClass('ve-icon-align-right')){
			jQuery('select#font-' + jQuery(this).attr('element') + '-text-align').val('right').trigger('change');
		}
	});
	
}