<?php
VisualEditorCheck::check();


class VisualEditorCheck {
	
	
	public static function check(){
		if(isset($_GET['visual-editor'])){
			//If user is logged in and user can't use VE, don't do anything
			if(is_user_logged_in() && !headway_can_visually_edit()){
				return false;
				
			//If the user isn't logged in at all, do a redirect	
			} elseif(!is_user_logged_in()) {
				auth_redirect();
				
				return false;
			}
			
			global $visual_editor;
			$visual_editor = new VisualEditor;
			$visual_editor->init();
			
		} elseif(isset($_GET['ve-iframe'])) {
			add_action('wp', array('VisualEditorCheck', 'iframe'), 12);
			
		} elseif(headway_can_visually_edit()) {
			add_action('wp', array('VisualEditorCheck', 'hooks'));
		}
	}
	
	
	public static function iframe(){
		wp_enqueue_style('headway-ve-iframe', get_bloginfo('template_directory').'/library/visual-editor/css/visual-editor-iframe.css');

		//Remove 3.1 bar
		if(function_exists('show_admin_bar')){
			show_admin_bar(false);
			remove_action('wp_head', '_admin_bar_bump_cb');
		}
		
		add_action('headway_after_everything', array('VisualEditorCheck', 'iframe_live_css'));

		remove_action('headway_before_everything', array('VisualEditorCheck', 'link'), 1);
		wp_deregister_style('visual-editor-mini');
	}
	
	
	public static function iframe_live_css(){
		echo '<style id="live-css-holder">'.stripslashes(headway_get_option('live-css')).'</style>';
	}
	
	
	public static function link(){
		$current_url = headway_current_url();

		$sign = (strpos($current_url, '?')) ? '&amp;' : '?';
		$system_page = headway_is_system_page(false, true) ? '&amp;visual-editor-system-page='.headway_current_page(true) : false;

		if(!isset($_GET['skin-preview']) && !defined('HEADWAYHIDEMENUS') && !isset($_GET['headway-skin-preview'])){	
			echo '<a href="'.$current_url.$sign.'visual-editor=true'.$system_page.'" class="visual-editor-link">'.__('Enter Visual Editor', 'headway').'</a>';
			echo '<a href="'.site_url().'/wp-admin" target="_blank" class="visual-editor-link wordpress-admin-link">'.__('WordPress Admin', 'headway').'</a>';
		}
	}
	
	
	public static function admin_menu_node(){
		if(!headway_can_visually_edit()) return false;

		$current_url = str_replace(array('dismiss-headway-nag=', 'headway-folder-nag', 'cache-folder-nag'), '', $_SERVER['REQUEST_URI']);

		$sign = (strpos($current_url, '?')) ? '&amp;' : '?';
		$system_page = headway_is_system_page(false, true) ? '&amp;visual-editor-system-page='.headway_current_page(true) : false;

		global $wp_admin_bar;
		$wp_admin_bar->add_menu(array('id' => 'headway-ve', 'title' => 'Headway Visual Editor',  'href' =>  $current_url.$sign.'visual-editor=true'.$system_page));
	}
	
	
	public static function hooks(){
		if(headway_get_option('hide-visual-editor-link')) return false;
		
		global $wp_admin_bar;
				
		if(isset($wp_admin_bar)){
			add_action('admin_bar_menu', array('VisualEditorCheck', 'admin_menu_node'), 75);
		} else {
			add_action('headway_before_everything', array('VisualEditorCheck', 'link'), 1);
			wp_enqueue_style('visual-editor-mini', get_bloginfo('template_directory').'/library/visual-editor/css/visual-editor-mini.css');
		}
	}
	
	
}


class VisualEditor {
	
	
	function init(){
		if(is_ie(7) || is_ie(6)){		
			header('Location:http://www.google.com/chrome');	
			return;
		}
		
		header("Cache-Control: no-cache, must-revalidate");
		header("Expires: Sat, 26 Jul 1997 05:00:00 GMT");
		
		//WordPress Multi-Site support API
		if(is_multisite()){
			require_once(ABSPATH.'wp-admin/includes/ms.php');
			require_once(ABSPATH.'wp-admin/includes/ms-deprecated.php');
		}
		
		//Load functions
		require_once HEADWAYLIBRARY.'/visual-editor/form-functions.php';

		//Load visual editor content
		require_once HEADWAYLIBRARY.'/visual-editor/content/boxes.php';
		require_once HEADWAYLIBRARY.'/visual-editor/content/panels.php';
		require_once HEADWAYLIBRARY.'/visual-editor/content/form.php';

		$this->remove_hooks();
		$this->deregister_scripts();
		
		$this->setup_hooks();
		
		$this->current_url = headway_current_url();
	}
	
	
	function display(){		
		$this->header();
				
		$bad = array(
			'/(.)(visual)(-)(editor)(=)((?:[a-z][a-z0-9_]*))/is',
			'/(.)(visual)(-)(editor)(-)(system)(-)(page)(=)((?:[a-z][a-z0-9_]*))/is'
		);
		
		$current_url = preg_replace($bad, '', $this->current_url);
		
		$fixed_url = (strpos($current_url, '?') !== false) ? $current_url.'&ve-iframe=true' : $current_url.'?ve-iframe=true';
		
		do_action('headway_pre_visual_editor');
		
		headway_ve_form_start();
		
		echo '<iframe src="'.$fixed_url.'" id="visual-editor-contents" scrolling="no"></iframe>';
		
		headway_ve_form_end();
				
		$this->footer();
	}
	
	
	function header(){
		headway_html_open();

		echo '<title>'.wp_title('', false).'</title>'."\n";
		echo '<meta http-equiv="content-type" content="'.get_bloginfo('html_type').'; charset='.get_bloginfo('charset').'" />'."\n\n";

		do_action('headway_ve_head');

		echo "\n\n".'</head><!-- End <head> -->'."\n\n";
	}
	
	
	function footer(){
		headway_html_close(); //Close <body> and <html>
	}
	
	
	function setup_hooks(){		
		add_filter('wp_title', array(&$this, 'visual_editor_title'), 12);
		
		add_action('headway_ve_head', array(&$this, 'enqueue_scripts'));
		add_action('headway_ve_head', array(&$this, 'enqueue_styles'));
		add_action('headway_ve_head', array(&$this, 'js_variables'), 12);
				
		add_action('headway_before_everything', 'headway_ve_form_start', 2);
		add_action('headway_after_everything', 'headway_ve_form_end', 2);
		
		add_action('init', array(&$this, 'redirect_fix'), 1);
		
		add_action('headway_ve', array(&$this, 'display'));
	}
	
	
	function enqueue_scripts(){
		echo '<script type="text/javascript" src="'.WPURL.'/wp-includes/js/l10n.js"></script>'."\n";
		echo '<script type="text/javascript" src="'.WPURL.'/wp-includes/js/jquery/jquery.js"></script>'."\n";
		
		echo '<script type="text/javascript" src="'.HEADWAYURL.'/library/visual-editor/js/jquery.ui.packed.js"></script>'."\n";
		echo '<script type="text/javascript" src="'.HEADWAYURL.'/library/visual-editor/js/visual-editor-includes.js"></script>'."\n";
		echo '<script type="text/javascript" src="'.HEADWAYURL.'/library/visual-editor/js/visual-editor-functions.js"></script>'."\n";
		echo '<script type="text/javascript" src="'.HEADWAYURL.'/library/visual-editor/js/visual-editor-options.js"></script>'."\n";

		echo '<script type="text/javascript" src="'.HEADWAYURL.'/library/visual-editor/js/visual-editor-leafs.js"></script>'."\n";
			
		if(!headway_get_option('disable-visual-editor') && !headway_get_option('enable-developer-mode') && !headway_is_skin_active())
			echo '<script type="text/javascript" src="'.HEADWAYURL.'/library/visual-editor/js/visual-editor-design-editor.js"></script>'."\n";
		

		echo '<script type="text/javascript" src="'.HEADWAYURL.'/library/visual-editor/js/visual-editor.js"></script>'."\n";
	}
	
	
	function enqueue_styles(){
		echo "\n".'<link rel="stylesheet" type="text/css" href="'.get_bloginfo('template_directory').'/library/visual-editor/css/visual-editor.css" id="headway-ve" />'."\n";
		echo '<link rel="stylesheet" type="text/css" href="'.get_bloginfo('template_directory').'/library/shared-media/css/colorpicker.css" id="headway-ve-colorpicker" />'."\n";
	}
	
	
	function js_variables(){
		echo '
<script type="text/javascript">
	headway_blog_url = \''.home_url().'\';
	headway_template_directory = \''.get_bloginfo('template_directory').'\';
</script>
		';
	}
	
	
	function remove_hooks(){
		global $headway_visual_editor_open;
		$headway_visual_editor_open = true;
		
		//Remove 3.1 bar
		if(function_exists('show_admin_bar')){
			show_admin_bar(false);
			remove_action('wp_head', '_admin_bar_bump_cb');
		}

		//Deactivate MU Domain Mapping
		remove_filter('plugins_url', 'domain_mapping_plugins_uri', 1);
		remove_filter('theme_root_uri', 'domain_mapping_themes_uri', 1);
		remove_filter('pre_option_siteurl', 'domain_mapping_siteurl');
		remove_filter('pre_option_home', 'domain_mapping_siteurl');
		remove_filter('the_content', 'domain_mapping_post_content');
		remove_action('wp_head', 'remote_login_js_loader');
		remove_action('login_head', 'redirect_login_to_orig');
		remove_action('wp_logout', 'remote_logout_loader', 9999);
		remove_action('template_redirect', 'redirect_to_mapped_domain');
	}
	
	
	function deregister_scripts(){
		wp_deregister_script('jquery-ui-core');
		wp_deregister_script('jquery-ui-tabs');
		wp_deregister_script('jquery-ui-draggable');
		wp_deregister_script('jquery-ui-droppable');
		wp_deregister_script('jquery-ui-resizable');
		wp_deregister_script('jquery-ui-sortable');
	}
	
	
	function redirect_fix(){
		if(strpos(site_url(), site_url()) !== false)
			return;

		$original_url = (function_exists('get_original_url')) ? get_original_url ('siteurl') : site_url();

		if(isset($_GET['visual-editor']) && strpos(headway_current_url(), $original_url) === false){
			header('Location:'.$original_url.'/?visual-editor=true');
			die();
		}
	}

	
	function visual_editor_title($title){
		return 'Visual Editor: Loading...';
	}


}